#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 socks
version:              0.6.1
visibility:           public
id:                   socks-0.6.1-2IVSfYShEqlA8SSdabT1D7
key:                  socks-0.6.1-2IVSfYShEqlA8SSdabT1D7
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-socks
synopsis:             Socks proxy (ver 5)
description:          Socks proxy (version 5) implementation.
category:             Network
abi:                  3244e9ae7a28172e2998b75fe08e67e8
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Wire Network.Socks5.Conf Network.Socks5.Command
    Network.Socks5.Parse

import-dirs:          /usr/lib/ghc-8.10.5/site-local/socks-0.6.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/socks-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/socks-0.6.1
hs-libraries:         HSsocks-0.6.1-2IVSfYShEqlA8SSdabT1D7
depends:
    base-4.14.2.0 basement-0.0.12-I5rgpQyLmajwT0dUlA8hE
    bytestring-0.10.12.0 cereal-0.5.8.1-4r85zOZIbEW4fo8WFnBuTl
    network-3.1.2.2-DhUKX0ZpAd35HJ7CPbrOZd

haddock-interfaces:   /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html:         /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

